/*
 * Copyright 2005 Berend "Kirk" Wouda
 * 
 * This file is part of WDYS'd V.
 * 
 * WDYS'd V is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * WDYS'd V is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with WDYS'd V; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// Batch...
package com.kirkwarez.wdysdv.batch;

// Yay ArrayList!
import java.util.*;

/**
 * The <code>Batch</code> class represents a batch of tasks, which you can process.
 * 
 * @author Berend "Kirk" Wouda
 * @version 5.00
 * @since 5.00
 */
public class Batch {
	/**
	 * Constructs a new, empty, batch.
	 */
	public Batch() {
		// Construct arraylist.
		batch = new ArrayList();
	}
	
	/**
	 * Constructs a new batch with an initial task. Useful for immediate processing.
	 */
	public Batch(Task task) {
		// Initialise
		this();
		
		// Add the initial task.
		addTask(task);
	}
	
	
	/**
	 * Returns the task at the index position in the batch.
	 * 
	 * @param index The position of the task in the batch.
	 * @return The task.
	 */
	public Task getTask(int index) {
		// Return the task.
		return (Task) batch.get(index);
	}
	
	/**
	 * Adds a task to the list.
	 * 
	 * @param task The task to be added.
	 */
	public void addTask(Task task) {
		// Check for nullity.
		if(task != null) {
			// Add the task.
			batch.add(task);
		}
		else  throw new IllegalArgumentException("Cannot add task: No null tasks allowed.");
	}
	
	/**
	 * Removes and returns the task at the index position in the batch.
	 * 
	 * @param index The position of the task in the batch.
	 * @return The removed task.
	 */
	public Task removeTask(int index) {
		// Remove and return the task.
		return (Task) batch.remove(index);
	}
	
	/**
	 * Removes all the task  in the batch.
	 */
	public void removeAllTasks() {
		// Remove all tasks.
		batch.clear();
	}
	
	
	/**
	 * Returns the length of this batch.
	 * 
	 * @return The number of tasks in this batch.
	 */
	public int getNumberOfTasks() {
		// Return the size of the list, since that's how may tasks there are. Capice?
		return batch.size();
	}
	
	
	/**
	 * Returns an iterator over the tasks.
	 */
	public Iterator getIterator() {
		// Get the list's iterator and use that.
		return batch.iterator();
	}
	
	
	/**
	 * The list of batch items.
	 */
	protected ArrayList batch;
}