/*
 * Copyright 2005 Berend "Kirk" Wouda
 * 
 * This file is part of WDYS'd V.
 * 
 * WDYS'd V is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * WDYS'd V is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with WDYS'd V; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// A GUI class.
package com.kirkwarez.wdysdv.gui;

// Import AWT classes.
import java.awt.*;
import java.io.File;

// Import the control class.
import com.kirkwarez.wdysdv.control.DisplayControl;

//Import old KirkPack classes.
import kirk.gui.layout.*;
import kirk.gui.dialog.*;

/**
 * This class is the window for displaying unencrypted file text/data.
 * 
 * @author Berend "Kirk" Wouda
 * @version 5.00
 * @since 5.00
 */
public class DisplayFrame extends Frame {
	/**
	 * Constructs a new display window.
	 * 
	 * @param control The control class to use for events and stuff.
	 * @param title The title of the new frame.
	 * @param text The text to display.
	 */
	public DisplayFrame(DisplayControl control, String title, String text) {
		// Set title and initialise superclass.
		super(title);
		
		
		// Store the control class.
		this.control = control;
		
		// Add control as the window listener too.
		addWindowListener(control);
		
		
		// Set the size.
		setSize(600, 600);
		
		// Locate the window in the middle of the screen.
		Dimension screensize = Toolkit.getDefaultToolkit().getScreenSize();
		setLocation((screensize.width - getWidth()) / 2, (screensize.height - getHeight()) / 2);
		
		
		// Color me grey. Or is it purple?
		setBackground(new Color(200, 200, 200));
		
		
		// Set the layout manager.
		setLayout(new GridSpanLayout(3, 12));
		
		// Lay out!
		GridSpanConstraints constraints;
		
		// Create and place the Save Uru Encrypted button.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(0);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(0.9);
		constraints.setVerticalFill(0.9);
		Button suebutton = new Button("Save Uru Encrypted");
		suebutton.setActionCommand("SAVEURUENCRYPTED");
		suebutton.addActionListener(control);
		add(suebutton, constraints);
		
		// Create and place the Save EOA Encrypted button.
		constraints = new GridSpanConstraints();
		constraints.setX(1);
		constraints.setY(0);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(0.9);
		constraints.setVerticalFill(0.9);
		Button svebutton = new Button("Save MYST V Encrypted");
		svebutton.setActionCommand("SAVEEOAENCRYPTED");
		svebutton.addActionListener(control);
		add(svebutton, constraints);
		
		// Create and place the Save Decrypted button.
		constraints = new GridSpanConstraints();
		constraints.setX(2);
		constraints.setY(0);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(0.9);
		constraints.setVerticalFill(0.9);
		Button sdbutton = new Button("Save Decrypted");
		sdbutton.setActionCommand("SAVEDECRYPTED");
		sdbutton.addActionListener(control);
		add(sdbutton, constraints);
		
		// Create and place the text area.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(1);
		constraints.setWidth(3);
		constraints.setHeight(11);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		area = new TextArea(text);
		add(area, constraints);
		
		
		// Show the window to the user.
		setVisible(true);
	}
	
	
	/**
	 * This method pops up the given error message.
	 * 
	 * @param message The message to be displayed.
	 */
	public void popupError(String message) {
		// Create the popup.
		ErrorDialog popup = new ErrorDialog(this, message);
		
		// Show the popup (this will also block this method until it is closed). 
		popup.show();
	}
	
	
	/**
	 * Pops up a <code>FileDialog</code> and returns the selected file.
	 * 
	 * @param title The title of the selection dialog.
	 * @param mode Whether it is about loading or saving.
	 * @return The selected filename.
	 */
	public File askForFileSelection(String title, int mode) {
		// Create a new FileDialog.
		FileDialog selection = new FileDialog(this, title, mode);
		
		// Pop it up.
		selection.show();
		
		// When we get here the user closed the file selection dialog.
		// Retrieve the filename.
		String dir = selection.getDirectory();
		String file = selection.getFile();
		
		// Check whether the dialog has been canceled. If so, return null. Otherwise
		// make a file of the dir and file and return that.
		if(dir == null || file == null)  return null;
		else  return new File(dir, file);
	}
	
	
	/**
	 * Returns the displayed text.
	 * 
	 * @return The text.
	 */
	public String getText() {
		// Return the text from the area.
		return area.getText();
	}
	
	
	/**
	 * The text area with the text.
	 */
	protected TextArea area;
	
	
	/**
	 * The associated control class.
	 */
	protected DisplayControl control;
}