/*
 * Copyright 2005 Berend "Kirk" Wouda
 * 
 * This file is part of WDYS'd V.
 * 
 * WDYS'd V is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * WDYS'd V is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with WDYS'd V; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// A GUI component.
package com.kirkwarez.wdysdv.gui;

// Import the AWT classes.
import java.awt.*;
import java.awt.event.*;

// Import my old GUI classes.
import kirk.gui.layout.*;

/**
 * This class is a GUI component that has a label, a text field and a file browse button.
 * 
 * @author Berend "Kirk" Wouda
 * @version 5.00
 * @since 5.00
 */
public class FilePanel extends Panel {
	/**
	 * Constructs a new file panel with the given stuff.
	 * 
	 * @param label The label of the panel.
	 * @param command The button command for the action listener.
	 * @param listener The action listener.
	 */
	public FilePanel(String label, String command, ActionListener listener) {
		// We don't need no stinkin' FlowLayout :^P
		super(new GridSpanLayout(10, 1));
		
		// Start adding components.
		GridSpanConstraints constraints;
		
		
		// Add the Label.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(0);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		Label zelabel = new Label(label, Label.LEFT);
		add(zelabel, constraints);
		
		// Add the TextField.
		constraints = new GridSpanConstraints();
		constraints.setX(1);
		constraints.setY(0);
		constraints.setWidth(6);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		filefield = new TextField();
		add(filefield, constraints);
		
		// The Browse button.
		constraints = new GridSpanConstraints();
		constraints.setX(7);
		constraints.setY(0);
		constraints.setWidth(2);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		Button button = new Button("Browse");
		button.setActionCommand(command);
		button.addActionListener(listener);
		add(button, constraints);
	}
	
	
	/**
	 * Returns the filename in the textfield.
	 * 
	 * @return The filename in the textfield.
	 */
	public String getFileName() {
		// Return the contents of the textfield.
		return filefield.getText();
	}
	
	/**
	 * Sets the filename in the textfield.
	 * 
	 * @param filename The filename for the textfield.
	 */
	public void setFileName(String filename) {
		// Set the contents of the textfield.
		filefield.setText(filename);
	}
	
	
	/**
	 * The field for the filename.
	 */
	protected TextField filefield;
}