/*
 * Copyright 2005 Berend "Kirk" Wouda
 * 
 * This file is part of WDYS'd V.
 * 
 * WDYS'd V is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * WDYS'd V is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with WDYS'd V; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// Main GUI class.
package com.kirkwarez.wdysdv.gui;

// Import AWT.
import java.awt.*;

// Import IO...
import java.io.*;

// Import control class.
import com.kirkwarez.wdysdv.control.WVControl;

// Import old KirkPack classes.
import kirk.gui.layout.*;
import kirk.gui.dialog.*;

// Import our Task class for the types.
import com.kirkwarez.wdysdv.batch.Task;

/**
 * The main GUI for WDYS'd.
 * 
 * @author Berend "Kirk" Wouda
 * @version 5.00
 * @since 5.00
 */
public class WVFrame extends Frame {
	/**
	 * Creates a new frame and initialises it.
	 */
	public WVFrame() {
		// Set title and initialise superclass.
		super("WDYS'd V (v5.00)");
		
		
		// Create control class. It serves as action listener so we need to create it
		// first thing!
		control = new WVControl(this);
		
		// Add control as a window listener too.
		addWindowListener(control);
		
		
		// Set the size.
		setSize(500, 500);
		
		// Locate the window in the middle of the screen.
		Dimension screensize = Toolkit.getDefaultToolkit().getScreenSize();
		setLocation((screensize.width - getWidth()) / 2, (screensize.height - getHeight()) / 2);
		
		
		// Color me purple. I mean grey.
		setBackground(new Color(200, 200, 200));
		
		
		// Create the checkbox groups.
		type = new CheckboxGroup();
		mode = new CheckboxGroup();
		
		// Set the layout manager.
		setLayout(new GridSpanLayout(6, 13));
		
		// Lay out!
		GridSpanConstraints constraints;
		
		
		// Add the big large list area.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(0);
		constraints.setWidth(6);
		constraints.setHeight(9);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		tasklist = new List();
		add(tasklist, constraints);
		
		
		// The Remove button.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(9);
		constraints.setWidth(2);
		constraints.setHeight(1);
		constraints.setHorizontalFill(0.8);
		constraints.setVerticalFill(0.8);
		Button rbutton = new Button("Remove");
		rbutton.setActionCommand("REMOVE");
		rbutton.addActionListener(control);
		add(rbutton, constraints);
		
		// The Remove All button.
		constraints = new GridSpanConstraints();
		constraints.setX(2);
		constraints.setY(9);
		constraints.setWidth(2);
		constraints.setHeight(1);
		constraints.setHorizontalFill(0.8);
		constraints.setVerticalFill(0.8);
		Button rabutton = new Button("Remove All");
		rabutton.setActionCommand("REMOVEALL");
		rabutton.addActionListener(control);
		add(rabutton, constraints);
		
		// The Send Back button.
		constraints = new GridSpanConstraints();
		constraints.setX(4);
		constraints.setY(9);
		constraints.setWidth(2);
		constraints.setHeight(1);
		constraints.setHorizontalFill(0.8);
		constraints.setVerticalFill(0.8);
		Button sbbutton = new Button("Send Back");
		sbbutton.setActionCommand("SENDBACK");
		sbbutton.addActionListener(control);
		add(sbbutton, constraints);
		
		
		// The Input panel.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(10);
		constraints.setWidth(4);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		inputpanel = new FilePanel("In:", "BROWSEIN", control);
		add(inputpanel, constraints);
		
		// The Output panel.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(11);
		constraints.setWidth(4);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		outputpanel = new FilePanel("Out:", "BROWSEOUT", control);
		add(outputpanel, constraints);
		
		
		// The Uru checkbox.
		constraints = new GridSpanConstraints();
		constraints.setX(4);
		constraints.setY(10);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		urubox = new Checkbox("Uru", false, type);
		urubox.addItemListener(control);
		add(urubox, constraints);
		
		// The MYST V checkbox.
		constraints = new GridSpanConstraints();
		constraints.setX(4);
		constraints.setY(11);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		eoabox = new Checkbox("MYST V", false, type);
		eoabox.addItemListener(control);
		add(eoabox, constraints);
		
		
		// The Encrypt checkbox.
		constraints = new GridSpanConstraints();
		constraints.setX(5);
		constraints.setY(10);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		encryptbox = new Checkbox("Encrypt", false, mode);
		encryptbox.addItemListener(control);
		add(encryptbox, constraints);
		
		// The Decrypt checkbox.
		constraints = new GridSpanConstraints();
		constraints.setX(5);
		constraints.setY(11);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		decryptbox = new Checkbox("Decrypt", false, mode);
		decryptbox.addItemListener(control);
		add(decryptbox, constraints);
		
		
		// The Batch button.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(12);
		constraints.setWidth(2);
		constraints.setHeight(1);
		constraints.setHorizontalFill(0.9);
		constraints.setVerticalFill(1.0);
		Button bbutton = new Button("Batch");
		bbutton.setActionCommand("BATCH");
		bbutton.addActionListener(control);
		add(bbutton, constraints);
		
		// The Open button.
		constraints = new GridSpanConstraints();
		constraints.setX(2);
		constraints.setY(12);
		constraints.setWidth(2);
		constraints.setHeight(1);
		constraints.setHorizontalFill(0.9);
		constraints.setVerticalFill(1.0);
		Button obutton = new Button("Open");
		obutton.setActionCommand("OPEN");
		obutton.addActionListener(control);
		add(obutton, constraints);
		
		// The Batch button.
		constraints = new GridSpanConstraints();
		constraints.setX(4);
		constraints.setY(12);
		constraints.setWidth(2);
		constraints.setHeight(1);
		constraints.setHorizontalFill(0.9);
		constraints.setVerticalFill(1.0);
		Button pbutton = new Button("Process");
		pbutton.setActionCommand("PROCESS");
		pbutton.addActionListener(control);
		add(pbutton, constraints);
		
		
		// Select the standard checkboxes.
		type.setSelectedCheckbox(urubox);
		mode.setSelectedCheckbox(encryptbox);
		
		// Show the window to the user.
		setVisible(true);
	}
	
	
	/**
	 * Pops up a message on a dialog with the given title.
	 * 
	 * @param title The title to use for the dialog.
	 * @param message The message to be displayed.
	 */
	public void popup(String title, String message) {
		// Create the popup.
		MessageDialog popup = new MessageDialog(this, title, message);
		
		// Show the popup (this will also block this method until it is closed). 
		popup.show();
	}
	
	/**
	 * This must be my favourite method or something, it's in each of my programs with a
	 * GUI.
	 * 
	 * @param message The message to be displayed.
	 */
	public void popup(String message) {
		// Overload.
		popup("Attention", message);
	}
	
	/**
	 * This method pops up the given error message.
	 * 
	 * @param message The message to be displayed.
	 */
	public void popupError(String message) {
		// Create the popup.
		ErrorDialog popup = new ErrorDialog(this, message);
		
		// Show the popup (this will also block this method until it is closed). 
		popup.show();
	}
	
	
	/**
	 * Pops up a <code>FileDialog</code> and returns the selected file.
	 * 
	 * @param title The title of the selection dialog.
	 * @param mode Whether it is about loading or saving.
	 * @return The selected filename.
	 */
	public File askForFileSelection(String title, int mode) {
		// Create a new FileDialog.
		FileDialog selection = new FileDialog(this, title, mode);
		
		// Pop it up.
		selection.show();
		
		// When we get here the user closed the file selection dialog.
		// Retrieve the filename.
		String dir = selection.getDirectory();
		String file = selection.getFile();
		
		// Check whether the dialog has been canceled. If so, return null. Otherwise
		// make a file of the dir and file and return that.
		if(dir == null || file == null)  return null;
		else  return new File(dir, file);
	}
	
	
	/**
	 * Replaces the current batch list with the given batch list.
	 * 
	 * @param list The new list.
	 */
	public void setBatchList(String[] list) {
		// Remove all the tasks from the list.
		tasklist.removeAll();
		
		// Go through the new list.
		for(int index = 0; index < list.length; index++) {
			// Add each item in that order.
			tasklist.add(list[index]);
		}
	}
	
	
	/**
	 * Returns the index of the task that is currently selected.
	 * 
	 * @return The index, or -1 if nothing is selected.
	 */
	public int getSelectedTask() {
		// Return the index of the selected task in the list.
		return tasklist.getSelectedIndex();
	}
	
	
	/**
	 * Retrieves what the user put in the input field, or null if he didn't put in
	 * anything.
	 * 
	 * @return The input file.
	 */
	public File getInFile() {
		// Retrieve the file from the input panel.
		String filename = inputpanel.getFileName();
		
		// Chexx.
		if(filename.equals(""))  return null;
		else  return new File(filename);
	}
	
	/**
	 * Sets the input field to the given file.
	 * 
	 * @param file The input file or null if none (empties the field).
	 */
	public void setInFile(File file) {
		// Get the filename and set it in the panel.
		if(file != null)  inputpanel.setFileName(file.getPath());
		else  inputpanel.setFileName("");
	}
	
	
	/**
	 * Retrieves what the user put in the output field, or null if he didn't put in
	 * anything.
	 * 
	 * @return The output file.
	 */
	public File getOutFile() {
		// Retrieve the file from the input panel.
		String filename = outputpanel.getFileName();
		
		// Chexx.
		if(filename.equals(""))  return null;
		else  return new File(filename);
	}
	
	/**
	 * Sets the output field to the given file.
	 * 
	 * @param file The output file or null if none (empties the field).
	 */
	public void setOutFile(File file) {
		// Get the filename and set it in the panel.
		if(file != null)  outputpanel.setFileName(file.getPath());
		else  outputpanel.setFileName("");
	}
	
	
	/**
	 * Retrieves the user selected type.
	 * 
	 * @return The type.
	 */
	public int getType() {
		// Ask the group which checkbox is selected.
		Checkbox box = type.getSelectedCheckbox();
		
		// Check which one it is.
		if(box == urubox)  return Task.URU;
		else if(box == eoabox)  return Task.EOA;
		else  throw new InternalError("Nonexistant type checkbox selected!");
	}
	
	/**
	 * Sets the type to the given type.
	 * 
	 * @param type The new type.
	 */
	public void setType(int type) {
		// Check for the type.
		if(type == Task.URU)  this.type.setSelectedCheckbox(urubox);
		else if(type == Task.EOA)  this.type.setSelectedCheckbox(eoabox);
		else  throw new InternalError("Couldn't select any checkbox: Unsupported type.");
	}
	
	
	/**
	 * Retrieves the user selected mode.
	 * 
	 * @return The mode.
	 */
	public int getMode() {
		// Ask the group which checkbox is selected.
		Checkbox box = mode.getSelectedCheckbox();
		
		// Check which one it is.
		if(box == encryptbox)  return Task.ENCRYPT;
		else if(box == decryptbox)  return Task.DECRYPT;
		else  throw new InternalError("Nonexistant mode checkbox selected!");
	}
	
	/**
	 * Sets the mode to the given mode.
	 * 
	 * @param mode The new mode.
	 */
	public void setMode(int mode) {
		// Check for the mode.
		if(mode == Task.ENCRYPT)  this.mode.setSelectedCheckbox(encryptbox);
		else if(mode == Task.DECRYPT)  this.mode.setSelectedCheckbox(decryptbox);
		else  throw new InternalError("Couldn't select any checkbox: Unsupported mode.");
	}
	
	
	/**
	 * The list of tasks.
	 */
	protected List tasklist;
	
	
	/**
	 * The input panel
	 */
	protected FilePanel inputpanel;
	
	/**
	 * The output panel
	 */
	protected FilePanel outputpanel;
	
	
	/**
	 * The checkbox group for the type.
	 */
	protected CheckboxGroup type;
	
	/**
	 * The Uru checkbox.
	 */
	protected Checkbox urubox;
	
	/**
	 * The MYST V checkbox.
	 */
	protected Checkbox eoabox;
	
	
	/**
	 * The checkbox group for the mode.
	 */
	protected CheckboxGroup mode;
	
	/**
	 * The Encrypt checkbox.
	 */
	protected Checkbox encryptbox;
	
	/**
	 * The Decrypt checkbox.
	 */
	protected Checkbox decryptbox;
	
	
	/**
	 * The associated control class. 
	 */
	protected WVControl control;
}